Created
June 27, 2017 20:20
-
-
Save marc1706/6b4945b5665a1d954b22fdee6487d306 to your computer and use it in GitHub Desktop.
Style changes phpBB 3.1.10 to 3.1.11-RC1
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff --git a/phpBB/styles/prosilver/style.cfg b/phpBB/styles/prosilver/style.cfg | |
index 300a831..019db11 100644 | |
--- a/phpBB/styles/prosilver/style.cfg | |
+++ b/phpBB/styles/prosilver/style.cfg | |
@@ -21,8 +21,8 @@ | |
# General Information about this style | |
name = prosilver | |
copyright = © phpBB Limited, 2007 | |
-style_version = 3.1.10 | |
-phpbb_version = 3.1.10 | |
+style_version = 3.1.11 | |
+phpbb_version = 3.1.11 | |
# Defining a different template bitfield | |
# template_bitfield = lNg= | |
diff --git a/phpBB/styles/prosilver/template/bbcode.html b/phpBB/styles/prosilver/template/bbcode.html | |
index 3e38d13..49bcd56 100644 | |
--- a/phpBB/styles/prosilver/template/bbcode.html | |
+++ b/phpBB/styles/prosilver/template/bbcode.html | |
@@ -18,13 +18,13 @@ | |
<!-- BEGIN inline_attachment_open --><div class="inline-attachment"><!-- END inline_attachment_open --> | |
<!-- BEGIN inline_attachment_close --></div><!-- END inline_attachment_close --> | |
-<!-- BEGIN b_open --><strong><!-- END b_open --> | |
+<!-- BEGIN b_open --><strong class="text-strong"><!-- END b_open --> | |
<!-- BEGIN b_close --></strong><!-- END b_close --> | |
<!-- BEGIN u_open --><span style="text-decoration: underline"><!-- END u_open --> | |
<!-- BEGIN u_close --></span><!-- END u_close --> | |
-<!-- BEGIN i_open --><em><!-- END i_open --> | |
+<!-- BEGIN i_open --><em class="text-italics"><!-- END i_open --> | |
<!-- BEGIN i_close --></em><!-- END i_close --> | |
<!-- BEGIN color --><span style="color: {COLOR}">{TEXT}</span><!-- END color --> | |
diff --git a/phpBB/styles/prosilver/template/forum_fn.js b/phpBB/styles/prosilver/template/forum_fn.js | |
index 99f3108..d779008 100644 | |
--- a/phpBB/styles/prosilver/template/forum_fn.js | |
+++ b/phpBB/styles/prosilver/template/forum_fn.js | |
@@ -57,7 +57,7 @@ function marklist(id, name, state) { | |
jQuery('#' + id + ' input[type=checkbox][name]').each(function() { | |
var $this = jQuery(this); | |
- if ($this.attr('name').substr(0, name.length) === name) { | |
+ if ($this.attr('name').substr(0, name.length) === name && !$this.prop('disabled')) { | |
$this.prop('checked', state); | |
} | |
}); | |
diff --git a/phpBB/styles/prosilver/template/forumlist_body.html b/phpBB/styles/prosilver/template/forumlist_body.html | |
index f8d6e36..a197545 100644 | |
--- a/phpBB/styles/prosilver/template/forumlist_body.html | |
+++ b/phpBB/styles/prosilver/template/forumlist_body.html | |
@@ -47,7 +47,7 @@ | |
<!-- EVENT forumlist_body_subforums_before --> | |
<br /><strong>{forumrow.L_SUBFORUM_STR}{L_COLON}</strong> | |
<!-- BEGIN subforum --> | |
- <a href="{forumrow.subforum.U_SUBFORUM}" class="subforum<!-- IF forumrow.subforum.S_UNREAD --> unread<!-- ELSE --> read<!-- ENDIF -->" title="<!-- IF forumrow.subforum.S_UNREAD -->{L_UNREAD_POSTS}<!-- ELSE -->{L_NO_UNREAD_POSTS}<!-- ENDIF -->">{forumrow.subforum.SUBFORUM_NAME}</a><!-- IF not forumrow.subforum.S_LAST_ROW -->{L_COMMA_SEPARATOR}<!-- ENDIF --> | |
+ <!-- EVENT forumlist_body_subforum_link_prepend --><a href="{forumrow.subforum.U_SUBFORUM}" class="subforum<!-- IF forumrow.subforum.S_UNREAD --> unread<!-- ELSE --> read<!-- ENDIF -->" title="<!-- IF forumrow.subforum.S_UNREAD -->{L_UNREAD_POSTS}<!-- ELSE -->{L_NO_UNREAD_POSTS}<!-- ENDIF -->">{forumrow.subforum.SUBFORUM_NAME}</a><!-- IF not forumrow.subforum.S_LAST_ROW -->{L_COMMA_SEPARATOR}<!-- ENDIF --><!-- EVENT forumlist_body_subforum_link_append --> | |
<!-- END subforum --> | |
<!-- EVENT forumlist_body_subforums_after --> | |
<!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/template/index_body.html b/phpBB/styles/prosilver/template/index_body.html | |
index ec5bf35..b292c40 100644 | |
--- a/phpBB/styles/prosilver/template/index_body.html | |
+++ b/phpBB/styles/prosilver/template/index_body.html | |
@@ -40,13 +40,18 @@ | |
<!-- IF U_VIEWONLINE --><h3><a href="{U_VIEWONLINE}">{L_WHO_IS_ONLINE}</a></h3><!-- ELSE --><h3>{L_WHO_IS_ONLINE}</h3><!-- ENDIF --> | |
<p> | |
<!-- EVENT index_body_block_online_prepend --> | |
- {TOTAL_USERS_ONLINE} ({L_ONLINE_EXPLAIN})<br />{RECORD_USERS}<br /> <br />{LOGGED_IN_USER_LIST} | |
- <!-- IF LEGEND --><br /><em>{L_LEGEND}{L_COLON} {LEGEND}</em><!-- ENDIF --> | |
+ {TOTAL_USERS_ONLINE} ({L_ONLINE_EXPLAIN})<br />{RECORD_USERS}<br /> | |
+ <!-- IF U_VIEWONLINE --> | |
+ <br />{LOGGED_IN_USER_LIST} | |
+ <!-- IF LEGEND --><br /><em>{L_LEGEND}{L_COLON} {LEGEND}</em><!-- ENDIF --> | |
+ <!-- ENDIF --> | |
<!-- EVENT index_body_block_online_append --> | |
</p> | |
</div> | |
<!-- ENDIF --> | |
+<!-- EVENT index_body_birthday_block_before --> | |
+ | |
<!-- IF S_DISPLAY_BIRTHDAY_LIST --> | |
<div class="stat-block birthday-list"> | |
<h3>{L_BIRTHDAYS}</h3> | |
diff --git a/phpBB/styles/prosilver/template/jumpbox.html b/phpBB/styles/prosilver/template/jumpbox.html | |
index 3096d08..fcd8ddb 100644 | |
--- a/phpBB/styles/prosilver/template/jumpbox.html | |
+++ b/phpBB/styles/prosilver/template/jumpbox.html | |
@@ -1,32 +1,34 @@ | |
-<!-- IF S_VIEWTOPIC --> | |
- <p class="jumpbox-return"><a href="{U_VIEW_FORUM}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r">{L_RETURN_TO_FORUM}</a></p> | |
-<!-- ELSEIF S_VIEWFORUM --> | |
- <p class="jumpbox-return"><a href="{U_INDEX}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r">{L_RETURN_TO_INDEX}</a></p> | |
-<!-- ELSEIF SEARCH_TOPIC --> | |
- <p class="jumpbox-return"><a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH_TOPIC}" accesskey="r">{L_RETURN_TO_TOPIC}</a></p> | |
-<!-- ELSEIF S_SEARCH_ACTION --> | |
- <p class="jumpbox-return"><a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH}" title="{L_SEARCH_ADV}" accesskey="r">{L_GO_TO_SEARCH_ADV}</a></p> | |
-<!-- ENDIF --> | |
+<div class="action-bar actions-jump"> | |
+ <!-- IF S_VIEWTOPIC --> | |
+ <p class="jumpbox-return"><a href="{U_VIEW_FORUM}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r">{L_RETURN_TO_FORUM}</a></p> | |
+ <!-- ELSEIF S_VIEWFORUM --> | |
+ <p class="jumpbox-return"><a href="{U_INDEX}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" accesskey="r">{L_RETURN_TO_INDEX}</a></p> | |
+ <!-- ELSEIF SEARCH_TOPIC --> | |
+ <p class="jumpbox-return"><a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH_TOPIC}" accesskey="r">{L_RETURN_TO_TOPIC}</a></p> | |
+ <!-- ELSEIF S_SEARCH_ACTION --> | |
+ <p class="jumpbox-return"><a class="left-box arrow-{S_CONTENT_FLOW_BEGIN}" href="{U_SEARCH}" title="{L_SEARCH_ADV}" accesskey="r">{L_GO_TO_SEARCH_ADV}</a></p> | |
+ <!-- ENDIF --> | |
-<!-- IF S_DISPLAY_JUMPBOX --> | |
+ <!-- IF S_DISPLAY_JUMPBOX --> | |
- <div class="dropdown-container dropdown-container-{S_CONTENT_FLOW_END}<!-- IF not S_IN_MCP --> dropdown-up<!-- ENDIF --> dropdown-{S_CONTENT_FLOW_BEGIN} dropdown-button-control" id="jumpbox"> | |
- <span title="<!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF -->" class="dropdown-trigger button dropdown-select"> | |
- <!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF --> | |
- </span> | |
- <div class="dropdown hidden"> | |
- <div class="pointer"><div class="pointer-inner"></div></div> | |
- <ul class="dropdown-contents"> | |
- <!-- BEGIN jumpbox_forums --> | |
- <!-- IF jumpbox_forums.FORUM_ID neq -1 --> | |
- <li><!-- BEGIN level --> <!-- END level --><a href="{jumpbox_forums.LINK}">{jumpbox_forums.FORUM_NAME}</a></li> | |
- <!-- ENDIF --> | |
- <!-- END jumpbox_forums --> | |
- </ul> | |
+ <div class="dropdown-container dropdown-container-{S_CONTENT_FLOW_END}<!-- IF not S_IN_MCP --> dropdown-up<!-- ENDIF --> dropdown-{S_CONTENT_FLOW_BEGIN} dropdown-button-control" id="jumpbox"> | |
+ <span title="<!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF -->" class="dropdown-trigger button dropdown-select"> | |
+ <!-- IF S_IN_MCP and S_MERGE_SELECT -->{L_SELECT_TOPICS_FROM}<!-- ELSEIF S_IN_MCP -->{L_MODERATE_FORUM}<!-- ELSE -->{L_JUMP_TO}<!-- ENDIF --> | |
+ </span> | |
+ <div class="dropdown hidden"> | |
+ <div class="pointer"><div class="pointer-inner"></div></div> | |
+ <ul class="dropdown-contents"> | |
+ <!-- BEGIN jumpbox_forums --> | |
+ <!-- IF jumpbox_forums.FORUM_ID neq -1 --> | |
+ <li><!-- BEGIN level --> <!-- END level --><a href="{jumpbox_forums.LINK}">{jumpbox_forums.FORUM_NAME}</a></li> | |
+ <!-- ENDIF --> | |
+ <!-- END jumpbox_forums --> | |
+ </ul> | |
+ </div> | |
</div> | |
- </div> | |
-<!-- ELSE --> | |
- <br /><br /> | |
-<!-- ENDIF --> | |
+ <!-- ELSE --> | |
+ </br></br> | |
+ <!-- ENDIF --> | |
+</div> | |
diff --git a/phpBB/styles/prosilver/template/mcp_forum.html b/phpBB/styles/prosilver/template/mcp_forum.html | |
index 3033ef7..4c037f5 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_forum.html | |
+++ b/phpBB/styles/prosilver/template/mcp_forum.html | |
@@ -120,6 +120,7 @@ | |
</div> | |
</div> | |
+<!-- EVENT mcp_forum_actions_before --> | |
<fieldset class="display-actions"> | |
<!-- IF not S_MERGE_SELECT --> | |
<select name="action"> | |
@@ -137,12 +138,14 @@ | |
<option value="make_announce">{L_MAKE_ANNOUNCE}</option> | |
<option value="make_global">{L_MAKE_GLOBAL}</option> | |
<!-- ENDIF --> | |
+ <!-- EVENT mcp_forum_actions_append --> | |
</select> | |
<input class="button2" type="submit" value="{L_SUBMIT}" /> | |
<div><a href="#" onclick="marklist('mcp', 'topic_id_list', true); return false;">{L_MARK_ALL}</a> :: <a href="#" onclick="marklist('mcp', 'topic_id_list', false); return false;">{L_UNMARK_ALL}</a></div> | |
<!-- ENDIF --> | |
{S_FORM_TOKEN} | |
</fieldset> | |
+<!-- EVENT mcp_forum_actions_after --> | |
</form> | |
<!-- INCLUDE mcp_footer.html --> | |
diff --git a/phpBB/styles/prosilver/template/mcp_post.html b/phpBB/styles/prosilver/template/mcp_post.html | |
index e5777d2..5acdcef 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_post.html | |
+++ b/phpBB/styles/prosilver/template/mcp_post.html | |
@@ -294,6 +294,14 @@ | |
</tbody> | |
</table> | |
+ <div class="pagination"> | |
+ <!-- INCLUDE pagination.html --> | |
+ </div> | |
+ </div> | |
+ </div> | |
+ | |
+ <div class="panel"> | |
+ <div class="inner"> | |
<table class="table1"> | |
<thead> | |
<tr> | |
@@ -315,7 +323,27 @@ | |
</tbody> | |
</table> | |
- <p><a href="{U_LOOKUP_ALL}#ip">{L_LOOKUP_ALL}</a></p> | |
+ <div class="buttons"> | |
+ <p><a href="{U_LOOKUP_ALL}#ip">{L_LOOKUP_ALL}</a></p> | |
+ </div> | |
+ | |
+ <div class="pagination"> | |
+ <ul> | |
+ <!-- BEGIN pagination_ips --> | |
+ <!-- IF pagination_ips.S_IS_PREV --> | |
+ <li class="previous"><a href="{pagination_ips.PAGE_URL}" rel="prev" role="button">{L_PREVIOUS}</a></li> | |
+ <!-- ELSEIF pagination_ips.S_IS_CURRENT --> | |
+ <li class="active"><span>{pagination_ips.PAGE_NUMBER}</span></li> | |
+ <!-- ELSEIF pagination_ips.S_IS_ELLIPSIS --> | |
+ <li class="ellipsis" role="separator"><span>{L_ELLIPSIS}</span></li> | |
+ <!-- ELSEIF pagination_ips.S_IS_NEXT --> | |
+ <li class="next"><a href="{pagination_ips.PAGE_URL}" rel="next" role="button">{L_NEXT}</a></li> | |
+ <!-- ELSE --> | |
+ <li><a href="{pagination_ips.PAGE_URL}" role="button">{pagination_ips.PAGE_NUMBER}</a></li> | |
+ <!-- ENDIF --> | |
+ <!-- END pagination_ips --> | |
+ </ul> | |
+ </div> | |
</div> | |
</div> | |
diff --git a/phpBB/styles/prosilver/template/mcp_topic.html b/phpBB/styles/prosilver/template/mcp_topic.html | |
index 22d837b..af4b632 100644 | |
--- a/phpBB/styles/prosilver/template/mcp_topic.html | |
+++ b/phpBB/styles/prosilver/template/mcp_topic.html | |
@@ -111,7 +111,9 @@ | |
</li> | |
</ul> | |
+ <!-- EVENT mcp_topic_postrow_post_subject_before --> | |
<h3><a href="{postrow.U_POST_DETAILS}">{postrow.POST_SUBJECT}</a></h3> | |
+ <!-- EVENT mcp_topic_postrow_post_subject_after --> | |
<!-- EVENT mcp_topic_postrow_post_details_before --> | |
<p class="author"><a href="#pr{postrow.POST_ID}">{postrow.MINI_POST_IMG}</a> {L_POSTED} {postrow.POST_DATE} {L_POST_BY_AUTHOR} <strong>{postrow.POST_AUTHOR_FULL}</strong><!-- IF postrow.U_MCP_DETAILS --> [ <a href="{postrow.U_MCP_DETAILS}">{L_POST_DETAILS}</a> ]<!-- ENDIF --></p> | |
diff --git a/phpBB/styles/prosilver/template/memberlist_team.html b/phpBB/styles/prosilver/template/memberlist_team.html | |
index b7f2d66..327dde4 100644 | |
--- a/phpBB/styles/prosilver/template/memberlist_team.html | |
+++ b/phpBB/styles/prosilver/template/memberlist_team.html | |
@@ -19,7 +19,7 @@ | |
<tbody> | |
<!-- BEGIN user --> | |
<tr class="<!-- IF group.user.S_ROW_COUNT is even -->bg1<!-- ELSE -->bg2<!-- ENDIF --><!-- IF group.user.S_INACTIVE --> inactive<!-- ENDIF -->"> | |
- <td><!-- IF group.user.RANK_IMG --><span class="rank-img">{group.user.RANK_IMG}</span><!-- ELSE --><span class="rank-img">{group.user.RANK_TITLE}</span><!-- ENDIF -->{group.user.USERNAME_FULL}<!-- IF group.user.S_INACTIVE --> ({L_INACTIVE})<!-- ENDIF --></td> | |
+ <td><!-- IF group.user.RANK_IMG --><span class="rank-img">{group.user.RANK_IMG}</span><!-- ELSE --><span class="rank-img">{group.user.RANK_TITLE}</span><!-- ENDIF --><!-- EVENT memberlist_team_username_prepend -->{group.user.USERNAME_FULL}<!-- IF group.user.S_INACTIVE --> ({L_INACTIVE})<!-- ENDIF --><!-- EVENT memberlist_team_username_append --></td> | |
<td class="info"><!-- IF group.user.U_GROUP --> | |
<a<!-- IF group.user.GROUP_COLOR --> style="font-weight: bold; color: #{group.user.GROUP_COLOR}"<!-- ENDIF --> href="{group.user.U_GROUP}">{group.user.GROUP_NAME}</a> | |
<!-- ELSE --> | |
diff --git a/phpBB/styles/prosilver/template/navbar_header.html b/phpBB/styles/prosilver/template/navbar_header.html | |
index e948e2e..bdfb5fb 100644 | |
--- a/phpBB/styles/prosilver/template/navbar_header.html | |
+++ b/phpBB/styles/prosilver/template/navbar_header.html | |
@@ -18,7 +18,7 @@ | |
<!-- IF S_USER_LOGGED_IN --> | |
<li class="small-icon icon-search-new"><a href="{U_SEARCH_NEW}" role="menuitem">{L_SEARCH_NEW}</a></li> | |
<!-- ENDIF --> | |
- <!-- IF S_LOAD_UNREADS --> | |
+ <!-- IF S_LOAD_UNREADS --> | |
<li class="small-icon icon-search-unread"><a href="{U_SEARCH_UNREAD}" role="menuitem">{L_SEARCH_UNREAD}</a></li> | |
<!-- ENDIF --> | |
<li class="small-icon icon-search-unanswered"><a href="{U_SEARCH_UNANSWERED}" role="menuitem">{L_SEARCH_UNANSWERED}</a></li> | |
@@ -55,14 +55,14 @@ | |
<div class="pointer"><div class="pointer-inner"></div></div> | |
<ul class="dropdown-contents" role="menu"> | |
<!-- IF U_RESTORE_PERMISSIONS --><li class="small-icon icon-restore-permissions"><a href="{U_RESTORE_PERMISSIONS}">{L_RESTORE_PERMISSIONS}</a></li><!-- ENDIF --> | |
- | |
+ | |
<!-- EVENT navbar_header_profile_list_before --> | |
- | |
+ | |
<li class="small-icon icon-ucp"><a href="{U_PROFILE}" title="{L_PROFILE}" role="menuitem">{L_PROFILE}</a></li> | |
<li class="small-icon icon-profile"><a href="{U_USER_PROFILE}" title="{L_READ_PROFILE}" role="menuitem">{L_READ_PROFILE}</a></li> | |
- | |
+ | |
<!-- EVENT navbar_header_profile_list_after --> | |
- | |
+ | |
<li class="separator"></li> | |
<li class="small-icon icon-logout"><a href="{U_LOGIN_LOGOUT}" title="{L_LOGIN_LOGOUT}" accesskey="x" role="menuitem">{L_LOGIN_LOGOUT}</a></li> | |
</ul> | |
@@ -72,12 +72,12 @@ | |
</li> | |
<!-- IF S_DISPLAY_PM --> | |
<li class="small-icon icon-pm rightside" data-skip-responsive="true"> | |
- <a href="{U_PRIVATEMSGS}" role="menuitem"><span>{L_PRIVATE_MESSAGES} [</span><strong>{PRIVATE_MESSAGE_COUNT}</strong><span>]</span></a> | |
+ <a href="{U_PRIVATEMSGS}" role="menuitem"><span>{L_PRIVATE_MESSAGES} </span><strong class="badge<!-- IF not PRIVATE_MESSAGE_COUNT --> hidden<!-- ENDIF -->">{PRIVATE_MESSAGE_COUNT}</strong></a> | |
</li> | |
<!-- ENDIF --> | |
<!-- IF S_NOTIFICATIONS_DISPLAY --> | |
<li class="small-icon icon-notification dropdown-container dropdown-{S_CONTENT_FLOW_END} rightside" data-skip-responsive="true"> | |
- <a href="{U_VIEW_ALL_NOTIFICATIONS}" id="notification_list_button" class="dropdown-trigger"><span>{L_NOTIFICATIONS} [</span><strong>{NOTIFICATIONS_COUNT}</strong><span>]</span></a> | |
+ <a href="{U_VIEW_ALL_NOTIFICATIONS}" id="notification_list_button" class="dropdown-trigger"><span>{L_NOTIFICATIONS} </span><strong class="badge<!-- IF not NOTIFICATIONS_COUNT --> hidden<!-- ENDIF -->">{NOTIFICATIONS_COUNT}</strong></a> | |
<!-- INCLUDE notification_dropdown.html --> | |
</li> | |
<!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/template/overall_header.html b/phpBB/styles/prosilver/template/overall_header.html | |
index 5093d81..e583c6e 100644 | |
--- a/phpBB/styles/prosilver/template/overall_header.html | |
+++ b/phpBB/styles/prosilver/template/overall_header.html | |
@@ -99,6 +99,7 @@ | |
</form> | |
</div> | |
<!-- ENDIF --> | |
+ <!-- EVENT overall_header_searchbox_after --> | |
</div> | |
<!-- EVENT overall_header_headerbar_after --> | |
diff --git a/phpBB/styles/prosilver/template/posting_attach_body.html b/phpBB/styles/prosilver/template/posting_attach_body.html | |
index 81b2c2b..d792229 100644 | |
--- a/phpBB/styles/prosilver/template/posting_attach_body.html | |
+++ b/phpBB/styles/prosilver/template/posting_attach_body.html | |
@@ -7,7 +7,7 @@ | |
<dl> | |
<dt><label for="fileupload">{L_FILENAME}{L_COLON}</label></dt> | |
<dd> | |
- <input type="file" name="fileupload" id="fileupload" maxlength="{FILESIZE}" value="" class="inputbox autowidth" /> | |
+ <input type="file" name="fileupload" id="fileupload" class="inputbox autowidth" /> | |
<input type="submit" name="add_file" value="{L_ADD_FILE}" class="button2" onclick="upload = true;" /> | |
</dd> | |
</dl> | |
diff --git a/phpBB/styles/prosilver/template/posting_topic_review.html b/phpBB/styles/prosilver/template/posting_topic_review.html | |
index c51d803..4d5ab16 100644 | |
--- a/phpBB/styles/prosilver/template/posting_topic_review.html | |
+++ b/phpBB/styles/prosilver/template/posting_topic_review.html | |
@@ -16,6 +16,10 @@ | |
<div class="post bg3 post-ignore"> | |
<div class="inner"> | |
{topic_review_row.L_IGNORE_POST} | |
+ <!-- ELSE IF topic_review_row.S_POST_DELETED --> | |
+ <div class="post bg3 post-ignore"> | |
+ <div class="inner"> | |
+ {topic_review_row.L_DELETE_POST} | |
<!-- ELSE --> | |
<div class="post <!-- IF topic_review_row.S_ROW_COUNT is odd -->bg1<!-- ELSE -->bg2<!-- ENDIF --><!-- IF topic_review_row.POST_ID == REPORTED_POST_ID --> reported<!-- ENDIF -->"> | |
<div class="inner"> | |
diff --git a/phpBB/styles/prosilver/template/search_results.html b/phpBB/styles/prosilver/template/search_results.html | |
index b6c454b..4c83e95 100644 | |
--- a/phpBB/styles/prosilver/template/search_results.html | |
+++ b/phpBB/styles/prosilver/template/search_results.html | |
@@ -76,6 +76,7 @@ | |
<!-- IF searchresults.S_TOPIC_UNAPPROVED or searchresults.S_POSTS_UNAPPROVED --><a href="{searchresults.U_MCP_QUEUE}">{searchresults.UNAPPROVED_IMG}</a> <!-- ENDIF --> | |
<!-- IF searchresults.S_TOPIC_DELETED --><a href="{searchresults.U_MCP_QUEUE}">{DELETED_IMG}</a> <!-- ENDIF --> | |
<!-- IF searchresults.S_TOPIC_REPORTED --><a href="{searchresults.U_MCP_REPORT}">{REPORTED_IMG}</a><!-- ENDIF --><br /> | |
+ <!-- EVENT topiclist_row_topic_title_after --> | |
<!-- IF .searchresults.pagination --> | |
<div class="pagination"> | |
<ul> | |
@@ -91,7 +92,6 @@ | |
</div> | |
<!-- ENDIF --> | |
<!-- IF searchresults.S_HAS_POLL -->{POLL_IMG} <!-- ENDIF --> | |
- <!-- EVENT topiclist_row_topic_title_after --> | |
{L_POST_BY_AUTHOR} {searchresults.TOPIC_AUTHOR_FULL} » {searchresults.FIRST_POST_TIME} » {L_IN} <a href="{searchresults.U_VIEW_FORUM}">{searchresults.FORUM_TITLE}</a> | |
<!-- EVENT topiclist_row_append --> | |
@@ -137,6 +137,7 @@ | |
<dd class="search-result-date">{searchresults.POST_DATE}</dd> | |
<dd>{L_FORUM}{L_COLON} <a href="{searchresults.U_VIEW_FORUM}">{searchresults.FORUM_TITLE}</a></dd> | |
<dd>{L_TOPIC}{L_COLON} <a href="{searchresults.U_VIEW_TOPIC}">{searchresults.TOPIC_TITLE}</a></dd> | |
+ <!-- EVENT search_results_topic_title_after --> | |
<dd>{L_REPLIES}{L_COLON} <strong>{searchresults.TOPIC_REPLIES}</strong></dd> | |
<dd>{L_VIEWS}{L_COLON} <strong>{searchresults.TOPIC_VIEWS}</strong></dd> | |
<!-- EVENT search_results_postprofile_after --> | |
diff --git a/phpBB/styles/prosilver/template/ucp_main_front.html b/phpBB/styles/prosilver/template/ucp_main_front.html | |
index 7bc8d40..056ea30 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_main_front.html | |
+++ b/phpBB/styles/prosilver/template/ucp_main_front.html | |
@@ -55,12 +55,14 @@ | |
<!-- EVENT ucp_main_front_user_activity_before --> | |
<dl class="details"> | |
+ <!-- EVENT ucp_main_front_user_activity_prepend --> | |
<dt>{L_JOINED}{L_COLON}</dt> <dd>{JOINED}</dd> | |
<dt>{L_LAST_ACTIVE}{L_COLON}</dt> <dd>{LAST_VISIT_YOU}</dd> | |
<dt>{L_TOTAL_POSTS}{L_COLON}</dt> <dd><!-- IF POSTS_PCT -->{POSTS}<!-- IF S_DISPLAY_SEARCH --> | <strong><a href="{U_SEARCH_USER}">{L_SEARCH_YOUR_POSTS}</a></strong><!-- ENDIF --><br />({POSTS_DAY} / {POSTS_PCT})<!-- ELSE -->{POSTS}<!-- ENDIF --></dd> | |
<!-- IF ACTIVE_FORUM != '' --><dt>{L_ACTIVE_IN_FORUM}{L_COLON}</dt> <dd><strong><a href="{U_ACTIVE_FORUM}">{ACTIVE_FORUM}</a></strong><br />({ACTIVE_FORUM_POSTS} / {ACTIVE_FORUM_PCT})</dd><!-- ENDIF --> | |
<!-- IF ACTIVE_TOPIC != '' --><dt>{L_ACTIVE_IN_TOPIC}{L_COLON}</dt> <dd><strong><a href="{U_ACTIVE_TOPIC}">{ACTIVE_TOPIC}</a></strong><br />({ACTIVE_TOPIC_POSTS} / {ACTIVE_TOPIC_PCT})</dd><!-- ENDIF --> | |
<!-- IF WARNINGS --><dt>{L_YOUR_WARNINGS}{L_COLON}</dt> <dd class="error">{WARNING_IMG} [{WARNINGS}]</dd><!-- ENDIF --> | |
+ <!-- EVENT ucp_main_front_user_activity_append --> | |
</dl> | |
<!-- EVENT ucp_main_front_user_activity_after --> | |
diff --git a/phpBB/styles/prosilver/template/ucp_main_subscribed.html b/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
index ef03317..2d65b80 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
+++ b/phpBB/styles/prosilver/template/ucp_main_subscribed.html | |
@@ -30,7 +30,7 @@ | |
{forumrow.FORUM_DESC} | |
<!-- IF forumrow.LAST_POST_TIME --> | |
<div class="responsive-show" style="display: none;"> | |
- {L_LAST_POST} {L_POST_BY_AUTHOR} {forumrow.LAST_POST_AUTHOR_FULL} « <a href="{topicrow.U_LAST_POST}">{forumrow.LAST_POST_TIME}</a> | |
+ {L_LAST_POST} {L_POST_BY_AUTHOR} {forumrow.LAST_POST_AUTHOR_FULL} « <a href="{forumrow.U_LAST_POST}">{forumrow.LAST_POST_TIME}</a> | |
</div> | |
<!-- ENDIF --> | |
</div> | |
@@ -113,9 +113,9 @@ | |
<div class="action-bar bottom"> | |
<div class="pagination"> | |
{TOTAL_TOPICS} | |
- <!-- IF .pagination --> | |
+ <!-- IF .pagination --> | |
<!-- INCLUDE pagination.html --> | |
- <!-- ELSE --> | |
+ <!-- ELSE --> | |
• {PAGE_NUMBER} | |
<!-- ENDIF --> | |
</div> | |
diff --git a/phpBB/styles/prosilver/template/ucp_pm_viewmessage.html b/phpBB/styles/prosilver/template/ucp_pm_viewmessage.html | |
index d92b90a..009a9bf 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_pm_viewmessage.html | |
+++ b/phpBB/styles/prosilver/template/ucp_pm_viewmessage.html | |
@@ -146,6 +146,7 @@ | |
</div> | |
</div> | |
+<!-- EVENT ucp_pm_viewmessage_options_before --> | |
<!-- IF S_VIEW_MESSAGE --> | |
<fieldset class="display-options"> | |
<!-- IF U_PREVIOUS_PM --><a href="{U_PREVIOUS_PM}" class="left-box arrow-{S_CONTENT_FLOW_BEGIN}">{L_VIEW_PREVIOUS_PM}</a><!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/template/ucp_register.html b/phpBB/styles/prosilver/template/ucp_register.html | |
index 655c0fc..38413ad 100644 | |
--- a/phpBB/styles/prosilver/template/ucp_register.html | |
+++ b/phpBB/styles/prosilver/template/ucp_register.html | |
@@ -79,8 +79,6 @@ | |
<!-- ENDIF --> | |
<!-- IF S_COPPA --> | |
- | |
- | |
<div class="panel"> | |
<div class="inner"> | |
@@ -91,6 +89,8 @@ | |
</div> | |
<!-- ENDIF --> | |
+<!-- EVENT ucp_register_buttons_before --> | |
+ | |
<div class="panel"> | |
<div class="inner"> | |
diff --git a/phpBB/styles/prosilver/template/viewforum_body.html b/phpBB/styles/prosilver/template/viewforum_body.html | |
index 643b788..f6fc07e 100644 | |
--- a/phpBB/styles/prosilver/template/viewforum_body.html | |
+++ b/phpBB/styles/prosilver/template/viewforum_body.html | |
@@ -261,9 +261,9 @@ | |
<!-- INCLUDE jumpbox.html --> | |
-<!-- IF S_DISPLAY_ONLINE_LIST --> | |
+<!-- IF S_DISPLAY_ONLINE_LIST and U_VIEWONLINE --> | |
<div class="stat-block online-list"> | |
- <h3><!-- IF U_VIEWONLINE --><a href="{U_VIEWONLINE}">{L_WHO_IS_ONLINE}</a><!-- ELSE -->{L_WHO_IS_ONLINE}<!-- ENDIF --></h3> | |
+ <h3><a href="{U_VIEWONLINE}">{L_WHO_IS_ONLINE}</a></h3> | |
<p>{LOGGED_IN_USER_LIST}</p> | |
</div> | |
<!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/template/viewtopic_body.html b/phpBB/styles/prosilver/template/viewtopic_body.html | |
index d2a253b..22a7777 100644 | |
--- a/phpBB/styles/prosilver/template/viewtopic_body.html | |
+++ b/phpBB/styles/prosilver/template/viewtopic_body.html | |
@@ -408,9 +408,9 @@ | |
<!-- EVENT viewtopic_body_footer_before --> | |
<!-- INCLUDE jumpbox.html --> | |
-<!-- IF S_DISPLAY_ONLINE_LIST --> | |
+<!-- IF S_DISPLAY_ONLINE_LIST and U_VIEWONLINE --> | |
<div class="stat-block online-list"> | |
- <h3><!-- IF U_VIEWONLINE --><a href="{U_VIEWONLINE}">{L_WHO_IS_ONLINE}</a><!-- ELSE -->{L_WHO_IS_ONLINE}<!-- ENDIF --></h3> | |
+ <h3><a href="{U_VIEWONLINE}">{L_WHO_IS_ONLINE}</a></h3> | |
<p>{LOGGED_IN_USER_LIST}</p> | |
</div> | |
<!-- ENDIF --> | |
diff --git a/phpBB/styles/prosilver/theme/colours.css b/phpBB/styles/prosilver/theme/colours.css | |
index 29cf641..9095e61 100644 | |
--- a/phpBB/styles/prosilver/theme/colours.css | |
+++ b/phpBB/styles/prosilver/theme/colours.css | |
@@ -1161,3 +1161,8 @@ ul.linklist li.responsive-menu a.responsive-menu-link:hover:before, ul.linklist | |
li.notification-reported strong, li.notification-disapproved strong { | |
color: #D31141; | |
} | |
+ | |
+.badge { | |
+ background-color: #D31141; | |
+ color: #ffffff; | |
+} | |
diff --git a/phpBB/styles/prosilver/theme/common.css b/phpBB/styles/prosilver/theme/common.css | |
index 5dd5ecd..df923aa 100644 | |
--- a/phpBB/styles/prosilver/theme/common.css | |
+++ b/phpBB/styles/prosilver/theme/common.css | |
@@ -137,17 +137,27 @@ p.right { | |
} | |
p.jumpbox-return { | |
- margin-top: 1em; | |
+ margin-top: 10px; | |
+ margin-bottom: 0; | |
+ float: left; | |
} | |
b, strong { | |
font-weight: bold; | |
} | |
+.text-strong { | |
+ font-weight: bold; | |
+} | |
+ | |
i, em { | |
font-style: italic; | |
} | |
+.text-italics { | |
+ font-style: italic; | |
+} | |
+ | |
u { | |
text-decoration: underline; | |
} | |
@@ -1251,6 +1261,26 @@ ul.linklist:after, | |
margin-left: 58px; | |
} | |
+.badge { | |
+ border-radius: 10px; | |
+ opacity: 0.8; | |
+ text-align: center; | |
+ white-space: nowrap; | |
+ font-size: 10px; | |
+ line-height: 1; | |
+ float: right; | |
+ display: inline-block; | |
+ margin-left: 3px; | |
+ vertical-align: baseline; | |
+ position: relative; | |
+ top: 3px; | |
+ padding: 4px 6px; | |
+} | |
+ | |
+.badge.hidden { | |
+ display: none; | |
+} | |
+ | |
/* Navbar specific list items | |
----------------------------------------*/ | |
@@ -1281,10 +1311,6 @@ ul.linklist:after, | |
display: none; | |
} | |
-.compact .icon-notification > a > strong, .compact .icon-pm > a > strong { | |
- padding-left: 2px; | |
-} | |
- | |
.dropdown-page-jump .dropdown { | |
top: 20px; | |
} | |
diff --git a/phpBB/styles/prosilver/theme/content.css b/phpBB/styles/prosilver/theme/content.css | |
index 92a7db8..dfb9189 100644 | |
--- a/phpBB/styles/prosilver/theme/content.css | |
+++ b/phpBB/styles/prosilver/theme/content.css | |
@@ -493,6 +493,8 @@ blockquote.uncited { | |
padding: 3px; | |
border: 1px solid transparent; | |
font-size: 1em; | |
+ overflow-x: scroll; | |
+ word-wrap: normal; | |
} | |
.codebox p { | |
@@ -515,7 +517,7 @@ blockquote .codebox { | |
max-height: 200px; | |
white-space: normal; | |
padding-top: 5px; | |
- font: 0.9em Monaco, "Andale Mono","Courier New", Courier, mono; | |
+ font: 0.9em Monaco, "Andale Mono","Courier New", Courier, monospace; | |
line-height: 1.3em; | |
margin: 2px 0; | |
} | |
diff --git a/phpBB/styles/prosilver/theme/forms.css b/phpBB/styles/prosilver/theme/forms.css | |
index 777f011..235c230 100644 | |
--- a/phpBB/styles/prosilver/theme/forms.css | |
+++ b/phpBB/styles/prosilver/theme/forms.css | |
@@ -288,7 +288,7 @@ textarea.inputbox { | |
} | |
input[type="number"] { | |
- -moz-padding-end: inherit; | |
+ -moz-padding-end: 0; | |
} | |
input[type="search"] { |
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff --git a/phpBB/styles/subsilver2/style.cfg b/phpBB/styles/subsilver2/style.cfg | |
index 4c9abcc..65d8464 100644 | |
--- a/phpBB/styles/subsilver2/style.cfg | |
+++ b/phpBB/styles/subsilver2/style.cfg | |
@@ -21,8 +21,8 @@ | |
# General Information about this style | |
name = subsilver2 | |
copyright = © 2005 phpBB Limited | |
-style_version = 3.1.10 | |
-phpbb_version = 3.1.10 | |
+style_version = 3.1.11 | |
+phpbb_version = 3.1.11 | |
# Defining a different template bitfield | |
# template_bitfield = lNg= | |
diff --git a/phpBB/styles/subsilver2/template/forumlist_body.html b/phpBB/styles/subsilver2/template/forumlist_body.html | |
index 6c9b648..6b7f884 100644 | |
--- a/phpBB/styles/subsilver2/template/forumlist_body.html | |
+++ b/phpBB/styles/subsilver2/template/forumlist_body.html | |
@@ -56,7 +56,7 @@ | |
<!-- EVENT forumlist_body_subforums_before --> | |
<p class="forumdesc"><strong>{forumrow.L_SUBFORUM_STR}{L_COLON}</strong> | |
<!-- BEGIN subforum --> | |
- <a href="{forumrow.subforum.U_SUBFORUM}" class="subforum<!-- IF forumrow.subforum.S_UNREAD --> unread<!-- ELSE --> read<!-- ENDIF -->" title="<!-- IF forumrow.subforum.S_UNREAD -->{L_UNREAD_POSTS}<!-- ELSE -->{L_NO_UNREAD_POSTS}<!-- ENDIF -->">{forumrow.subforum.SUBFORUM_NAME}</a><!-- IF not forumrow.subforum.S_LAST_ROW -->{L_COMMA_SEPARATOR}<!-- ENDIF --> | |
+ <!-- EVENT forumlist_body_subforum_link_prepend --><a href="{forumrow.subforum.U_SUBFORUM}" class="subforum<!-- IF forumrow.subforum.S_UNREAD --> unread<!-- ELSE --> read<!-- ENDIF -->" title="<!-- IF forumrow.subforum.S_UNREAD -->{L_UNREAD_POSTS}<!-- ELSE -->{L_NO_UNREAD_POSTS}<!-- ENDIF -->">{forumrow.subforum.SUBFORUM_NAME}</a><!-- IF not forumrow.subforum.S_LAST_ROW -->{L_COMMA_SEPARATOR}<!-- ENDIF --><!-- EVENT forumlist_body_subforum_link_append --> | |
<!-- END subforum --> | |
</p> | |
<!-- EVENT forumlist_body_subforums_after --> | |
diff --git a/phpBB/styles/subsilver2/template/index_body.html b/phpBB/styles/subsilver2/template/index_body.html | |
index c0a8d5f..de1523b 100644 | |
--- a/phpBB/styles/subsilver2/template/index_body.html | |
+++ b/phpBB/styles/subsilver2/template/index_body.html | |
@@ -66,6 +66,8 @@ | |
</table> | |
<!-- ENDIF --> | |
+<!-- EVENT index_body_birthday_block_before --> | |
+ | |
<!-- IF S_DISPLAY_BIRTHDAY_LIST --> | |
<br clear="all" /> | |
diff --git a/phpBB/styles/subsilver2/template/mcp_forum.html b/phpBB/styles/subsilver2/template/mcp_forum.html | |
index ba4f16b..12447b2 100644 | |
--- a/phpBB/styles/subsilver2/template/mcp_forum.html | |
+++ b/phpBB/styles/subsilver2/template/mcp_forum.html | |
@@ -58,6 +58,7 @@ | |
<td class="row1" colspan="8" align="center"><p class="gen">{L_NO_TOPICS}</p></td> | |
</tr> | |
<!-- END topicrow --> | |
+<!-- EVENT mcp_forum_actions_before --> | |
<!-- IF not S_MERGE_SELECT --> | |
<tr> | |
<td class="cat" colspan="6" align="{S_CONTENT_FLOW_END}"> | |
@@ -76,11 +77,13 @@ | |
<option value="make_announce">{L_MAKE_ANNOUNCE}</option> | |
<option value="make_global">{L_MAKE_GLOBAL}</option> | |
<!-- ENDIF --> | |
+ <!-- EVENT mcp_forum_actions_append --> | |
</select> | |
<input class="btnmain" type="submit" value="{L_SUBMIT}" /> | |
</td> | |
</tr> | |
<!-- ENDIF --> | |
+<!-- EVENT mcp_forum_actions_after --> | |
</table> | |
{S_FORM_TOKEN} | |
</form> | |
diff --git a/phpBB/styles/subsilver2/template/memberlist_search.html b/phpBB/styles/subsilver2/template/memberlist_search.html | |
index 2096062..5a4c430 100644 | |
--- a/phpBB/styles/subsilver2/template/memberlist_search.html | |
+++ b/phpBB/styles/subsilver2/template/memberlist_search.html | |
@@ -54,7 +54,7 @@ | |
for (var r = 0; r < rb.length; r++) | |
{ | |
- if (rb[r].name.substr(0, name.length) == name) | |
+ if (rb[r].name.substr(0, name.length) == name && rb[r].disabled !== true) | |
{ | |
rb[r].checked = state; | |
} | |
diff --git a/phpBB/styles/subsilver2/template/memberlist_team.html b/phpBB/styles/subsilver2/template/memberlist_team.html | |
index 18995b6..75fade1 100644 | |
--- a/phpBB/styles/subsilver2/template/memberlist_team.html | |
+++ b/phpBB/styles/subsilver2/template/memberlist_team.html | |
@@ -17,7 +17,7 @@ | |
<!-- BEGIN user --> | |
<!-- IF group.user.S_ROW_COUNT is even --><tr class="row2"><!-- ELSE --><tr class="row1"><!-- ENDIF --> | |
- <td class="gen" align="center"><strong>{group.user.USERNAME_FULL}</strong><!-- IF group.user.S_INACTIVE --> <em>({L_INACTIVE})</em><!-- ENDIF --></td> | |
+ <td class="gen" align="center"><!-- EVENT memberlist_team_username_prepend --><strong>{group.user.USERNAME_FULL}</strong><!-- IF group.user.S_INACTIVE --> <em>({L_INACTIVE})</em><!-- ENDIF --><!-- EVENT memberlist_team_username_append --></td> | |
<!-- IF S_DISPLAY_MODERATOR_FORUMS --><td class="gensmall" align="center"><!-- IF group.user.FORUM_OPTIONS --><select style="width: 100%;">{group.user.FORUMS}</select><!-- ELSEIF group.user.FORUMS -->{group.user.FORUMS}<!-- ELSE -->-<!-- ENDIF --></td><!-- ENDIF --> | |
<td class="gensmall" align="center" nowrap="nowrap"> | |
<!-- IF group.user.U_GROUP --> | |
diff --git a/phpBB/styles/subsilver2/template/overall_header.html b/phpBB/styles/subsilver2/template/overall_header.html | |
index a418578..ae3d482 100644 | |
--- a/phpBB/styles/subsilver2/template/overall_header.html | |
+++ b/phpBB/styles/subsilver2/template/overall_header.html | |
@@ -83,7 +83,7 @@ function marklist(id, name, state) | |
for (var r = 0; r < rb.length; r++) | |
{ | |
- if (rb[r].name.substr(0, name.length) == name) | |
+ if (rb[r].name.substr(0, name.length) == name && rb[r].disabled !== true) | |
{ | |
rb[r].checked = state; | |
} | |
diff --git a/phpBB/styles/subsilver2/template/ucp_main_front.html b/phpBB/styles/subsilver2/template/ucp_main_front.html | |
index 7fc906a..485a58b 100644 | |
--- a/phpBB/styles/subsilver2/template/ucp_main_front.html | |
+++ b/phpBB/styles/subsilver2/template/ucp_main_front.html | |
@@ -38,6 +38,7 @@ | |
<!-- EVENT ucp_main_front_user_activity_before --> | |
<td class="row1" colspan="3"> | |
<table width="100%" cellspacing="1" cellpadding="4"> | |
+ <!-- EVENT ucp_main_front_user_activity_prepend --> | |
<tr> | |
<td align="{S_CONTENT_FLOW_END}" valign="top" nowrap="nowrap"><b class="genmed">{L_JOINED}{L_COLON} </b></td> | |
<td width="100%"><b class="gen">{JOINED}</b></td> | |
@@ -62,6 +63,7 @@ | |
<td class="genmed">{WARNING_IMG} [ <b>{WARNINGS}</b> ]</td> | |
</tr> | |
<!-- ENDIF --> | |
+ <!-- EVENT ucp_main_front_user_activity_append --> | |
</table> | |
</td> | |
<!-- EVENT ucp_main_front_user_activity_after --> | |
diff --git a/phpBB/styles/subsilver2/template/ucp_register.html b/phpBB/styles/subsilver2/template/ucp_register.html | |
index 9b9e164..db26f51 100644 | |
--- a/phpBB/styles/subsilver2/template/ucp_register.html | |
+++ b/phpBB/styles/subsilver2/template/ucp_register.html | |
@@ -91,6 +91,8 @@ | |
</tr> | |
<!-- ENDIF --> | |
+<!-- EVENT ucp_register_buttons_before --> | |
+ | |
<tr> | |
<td class="cat" colspan="2" align="center">{S_HIDDEN_FIELDS}<input class="btnmain" type="submit" name="submit" id="submit" value="{L_SUBMIT}" /> <input class="btnlite" type="reset" value="{L_RESET}" name="reset" /></td> | |
</tr> |
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment
diff --git a/phpBB/styles/prosilver/template/ajax.js b/phpBB/styles/prosilver/template/ajax.js | |
index e3780f0..ec9b533 100644 | |
--- a/phpBB/styles/prosilver/template/ajax.js | |
+++ b/phpBB/styles/prosilver/template/ajax.js | |
@@ -132,9 +132,10 @@ phpbb.markNotifications = function($popup, unreadCount) { | |
// Update the unread count. | |
$('strong', '#notification_list_button').html(unreadCount); | |
// Remove the Mark all read link if there are no unread notifications. | |
if (!unreadCount) { | |
$('#mark_all_notifications').remove(); | |
+ $('#notification_list_button > strong').addClass('hidden'); | |
} | |
// Update page title | |
@@ -132,9 +132,10 @@ phpbb.markNotifications = function($popup, unreadCount) { | |
// Update the unread count. | |
$('strong', '#notification_list_button').html(unreadCount); | |
- // Remove the Mark all read link if there are no unread notifications. | |
+ // Remove the Mark all read link and hide notification count if there are no unread notifications. | |
if (!unreadCount) { | |
$('#mark_all_notifications').remove(); | |